@@ -57,7 +57,7 @@ class CfnByteMatchSet(
         '''
         props = CfnByteMatchSetProps(name=name, byte_match_tuples=byte_match_tuples)
 
-        jsii.create(CfnByteMatchSet, self, [scope, id, props])
+        jsii.create(self.__class__, self, [scope, id, props])
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
@@ -362,7 +362,7 @@ class CfnIPSet(
         '''
         props = CfnIPSetProps(name=name, ip_set_descriptors=ip_set_descriptors)
 
-        jsii.create(CfnIPSet, self, [scope, id, props])
+        jsii.create(self.__class__, self, [scope, id, props])
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
@@ -567,7 +567,7 @@ class CfnRule(
         '''
         props = CfnRuleProps(metric_name=metric_name, name=name, predicates=predicates)
 
-        jsii.create(CfnRule, self, [scope, id, props])
+        jsii.create(self.__class__, self, [scope, id, props])
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
@@ -814,7 +814,7 @@ class CfnSizeConstraintSet(
         '''
         props = CfnSizeConstraintSetProps(name=name, size_constraints=size_constraints)
 
-        jsii.create(CfnSizeConstraintSet, self, [scope, id, props])
+        jsii.create(self.__class__, self, [scope, id, props])
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
@@ -1107,7 +1107,7 @@ class CfnSqlInjectionMatchSet(
             name=name, sql_injection_match_tuples=sql_injection_match_tuples
         )
 
-        jsii.create(CfnSqlInjectionMatchSet, self, [scope, id, props])
+        jsii.create(self.__class__, self, [scope, id, props])
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
@@ -1382,7 +1382,7 @@ class CfnWebACL(
             rules=rules,
         )
 
-        jsii.create(CfnWebACL, self, [scope, id, props])
+        jsii.create(self.__class__, self, [scope, id, props])
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
@@ -1702,7 +1702,7 @@ class CfnXssMatchSet(
         '''
         props = CfnXssMatchSetProps(name=name, xss_match_tuples=xss_match_tuples)
 
-        jsii.create(CfnXssMatchSet, self, [scope, id, props])
+        jsii.create(self.__class__, self, [scope, id, props])
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
